# am4894bq
> A helper library for some BigQuery related stuff.


This file will become your README and also the index of your documentation.

## Install

`pip install am4894bq`

## How to use

Fill me in please! Don't forget code examples:

```python
say_hello("Joe")
```




    'Hello Joe!'



```python
say_hello2("Joe")
```
